@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2018 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -10,58 +10,47 @@
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-#ifndef _MESH_DRAW_MGR_H_
-#define _MESH_DRAW_MGR_H_
+#pragma once
 
+// 1st
+#include "common.h"
+
+// System headers
+#include <vector>
+
+// common interface headers
 #include "bzfgl.h"
 #include "MeshDrawInfo.h"
 
-class MeshDrawMgr {
-  public:
+class MeshDrawMgr
+{
+public:
     MeshDrawMgr(const MeshDrawInfo* drawInfo);
     ~MeshDrawMgr();
 
-    void executeSet(int lod, int set, bool normals, bool texcoords);
+    void executeSet(int lod, int set, bool useNormals, bool useTexcoords);
     void executeSetGeometry(int lod, int set);
 
-    static void disableArrays();
-    static void init();
-    static void kill();
-
-  private:
+private:
     void rawExecuteCommands(int lod, int set);
-    static void rawDisableArrays();
 
     void makeLists();
     void freeLists();
     static void initContext(void* data);
     static void freeContext(void* data);
 
-  private:
+private:
     const MeshDrawInfo* drawInfo;
 
-    const DrawLod* drawLods;
-    const GLfloat* vertices;
-    const GLfloat* normals;
-    const GLfloat* texcoords;
-
-    struct LodList {
-      int count;
-      GLuint* setLists;
-    };
-
-    int lodCount;
-    LodList* lodLists;
-
-    static GLuint unloadList;
+    using LodList = std::vector<int>;
+    std::vector<LodList> lodLists;
 };
 
-#endif // _MESH_DRAW_MGR_H_
 
 // Local Variables: ***
 // mode: C++ ***
-// tab-width: 8 ***
-// c-basic-offset: 2 ***
-// indent-tabs-mode: t ***
+// tab-width: 4 ***
+// c-basic-offset: 4 ***
+// indent-tabs-mode: nil ***
 // End: ***
-// ex: shiftwidth=2 tabstop=8
+// ex: shiftwidth=4 tabstop=4
