@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2018 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -10,8 +10,8 @@
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-#ifndef	__HUDDIALOGSTACK_H__
-#define	__HUDDIALOGSTACK_H__
+#ifndef __HUDDIALOGSTACK_H__
+#define __HUDDIALOGSTACK_H__
 
 /* common header */
 #include "common.h"
@@ -24,27 +24,28 @@ class HUDDialog;
 
 /** general utility class for the HUDDialog
  */
-class HUDDialogStack {
+class HUDDialogStack
+{
 public:
-  static HUDDialogStack* get();
+    static HUDDialogStack* get();
 
-  bool isActive() const;
-  HUDDialog* top() const;
-  void push(HUDDialog*);
-  void pop();
+    bool isActive() const;
+    HUDDialog* top() const;
+    void push(HUDDialog*);
+    void pop();
 
-  void render();
-  void setFailedMessage(const char *msg);
+    void render();
+    void setFailedMessage(const char *msg);
 
-  HUDDialogStack();
-  ~HUDDialogStack();
+    HUDDialogStack();
+    ~HUDDialogStack();
 
 private:
-  static void resize(void*);
+    static void resize(void*);
 
 private:
-  std::vector<HUDDialog*> stack;
-  static HUDDialogStack globalStack;
+    std::vector<HUDDialog*> stack;
+    static HUDDialogStack globalStack;
 };
 
 
@@ -52,8 +53,8 @@ private:
 
 // Local Variables: ***
 // mode: C++ ***
-// tab-width: 8 ***
-// c-basic-offset: 2 ***
-// indent-tabs-mode: t ***
+// tab-width: 4 ***
+// c-basic-offset: 4 ***
+// indent-tabs-mode: nil ***
 // End: ***
-// ex: shiftwidth=2 tabstop=8
+// ex: shiftwidth=4 tabstop=4
