@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2018 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -10,8 +10,8 @@
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-#ifndef	__MAINMENU_H__
-#define	__MAINMENU_H__
+#ifndef __MAINMENU_H__
+#define __MAINMENU_H__
 
 #include "common.h"
 
@@ -25,32 +25,32 @@ class QuitMenu;
 
 /** MainMenu is the main menu
  */
-class MainMenu : public HUDDialog {
+class MainMenu : public HUDDialog
+{
 public:
-  MainMenu();
-  ~MainMenu();
+    MainMenu();
+    ~MainMenu();
 
-  HUDuiDefaultKey* getDefaultKey();
-  void execute();
-  void resize(int width, int height);
-  void createControls();
+    HUDuiDefaultKey* getDefaultKey();
+    void execute();
+    void resize(int width, int height);
+    void createControls();
 
-  static int getFontFace();
+    static int getFontFace();
 
 private:
 
-  HUDuiControl* createLabel(const char* string);
+    HUDuiControl* createLabel(const char* string);
 
-  HUDuiControl*	join;
-  HUDuiControl*	options;
-  HUDuiControl*	help;
-  HUDuiControl*	leave;
-  HUDuiControl*	save;
-  HUDuiControl*	quit;
+    HUDuiControl* join;
+    HUDuiControl* options;
+    HUDuiControl* help;
+    HUDuiControl* leave;
+    HUDuiControl* quit;
 
-  JoinMenu*	joinMenu;
-  OptionsMenu*	optionsMenu;
-  QuitMenu*	quitMenu;
+    JoinMenu* joinMenu;
+    OptionsMenu*  optionsMenu;
+    QuitMenu* quitMenu;
 };
 
 
@@ -58,8 +58,8 @@ private:
 
 // Local Variables: ***
 // mode: C++ ***
-// tab-width: 8 ***
-// c-basic-offset: 2 ***
-// indent-tabs-mode: t ***
+// tab-width: 4 ***
+// c-basic-offset: 4 ***
+// indent-tabs-mode: nil ***
 // End: ***
-// ex: shiftwidth=2 tabstop=8
+// ex: shiftwidth=4 tabstop=4
