@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2018 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -20,10 +20,11 @@
 #include "CommandManager.h"
 
 
-typedef struct CommandListItem {
-  const char* name;
-  CommandManager::CommandFunction func;
-  const char* help;
+typedef struct CommandListItem
+{
+    const char* name;
+    CommandManager::CommandFunction func;
+    const char* help;
 } CmdListItem;
 
 /* FIXME -- gcc is not liking array type with sizeof() without size
@@ -34,8 +35,8 @@ extern const CmdListItem commandList[29];
 
 // Local Variables: ***
 // mode: C++ ***
-// tab-width: 8 ***
-// c-basic-offset: 2 ***
-// indent-tabs-mode: t ***
+// tab-width: 4 ***
+// c-basic-offset: 4 ***
+// indent-tabs-mode: nil ***
 // End: ***
-// ex: shiftwidth=2 tabstop=8
+// ex: shiftwidth=4 tabstop=4
