@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2018 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -16,27 +16,29 @@
 /* interface header */
 #include "WorldFileObstacle.h"
 
-/* local interface headers */
-#include "WorldInfo.h"
-
 /* common interface headers */
 #include "BzMaterial.h"
 
+/* local interface headers */
+#include "WorldInfo.h"
 
-class CustomCone : public WorldFileObstacle {
-  public:
+
+class CustomCone : public WorldFileObstacle
+{
+public:
     CustomCone(bool pyramidStyle);
     ~CustomCone();
-    virtual bool read(const char* cmd, std::istream& input);
-    virtual void writeToGroupDef(GroupDefinition*) const;
+    bool read(const char* cmd, std::istream& input) override;
+    void writeToGroupDef(GroupDefinition*) override;
 
-  private:
-    enum {
-      Edge,
-      Bottom,
-      StartFace,
-      EndFace,
-      MaterialCount
+private:
+    enum
+    {
+        Edge,
+        Bottom,
+        StartFace,
+        EndFace,
+        MaterialCount
     };
     static const char* sideNames[MaterialCount];
 
@@ -56,8 +58,8 @@ class CustomCone : public WorldFileObstacle {
 
 // Local variables: ***
 // mode: C++ ***
-// tab-width: 8 ***
-// c-basic-offset: 2 ***
-// indent-tabs-mode: t ***
+// tab-width: 4***
+// c-basic-offset: 4 ***
+// indent-tabs-mode: nil ***
 // End: ***
-// ex: shiftwidth=2 tabstop=8
+// ex: shiftwidth=4 tabstop=4
