@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2018 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -16,22 +16,23 @@
 /* interface header */
 #include "WorldFileObstacle.h"
 
-/* local interface header */
-#include "WorldInfo.h"
-
 /* system header */
 #include <string>
 
 /* common interface header */
 #include "BzMaterial.h"
 
-class CustomTetra : public WorldFileObstacle {
-  public:
-    CustomTetra();
-    virtual bool read(const char *cmd, std::istream& input);
-    virtual void writeToGroupDef(GroupDefinition*) const;
+/* local interface header */
+#include "WorldInfo.h"
 
-  private:
+class CustomTetra : public WorldFileObstacle
+{
+public:
+    CustomTetra();
+    bool read(const char *cmd, std::istream& input) override;
+    void writeToGroupDef(GroupDefinition*) override;
+
+private:
     int vertexCount;
 
     float vertices[4][3];
@@ -46,8 +47,8 @@ class CustomTetra : public WorldFileObstacle {
 
 // Local variables: ***
 // mode: C++ ***
-// tab-width: 8 ***
-// c-basic-offset: 2 ***
-// indent-tabs-mode: t ***
+// tab-width: 4***
+// c-basic-offset: 4 ***
+// indent-tabs-mode: nil ***
 // End: ***
-// ex: shiftwidth=2 tabstop=8
+// ex: shiftwidth=4 tabstop=4
