@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2018 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -23,37 +23,38 @@
 // local implementation headers
 #include "GameKeeper.h"
 
-class ServerCommand {
- public:
+class ServerCommand
+{
+public:
 
-  static bool execute(const char	 *commandToken,
-		      GameKeeper::Player *playerData);
+    static bool execute(const char     *commandToken,
+                        GameKeeper::Player *playerData);
 
-  std::string getHelp();
+    std::string getHelp();
 
-  virtual bool operator() (const char	 *commandLine,
-			   GameKeeper::Player *playerData);
+    virtual bool operator() (const char    *commandLine,
+                             GameKeeper::Player *playerData);
 
 
- protected:
+protected:
 
-  ServerCommand(std::string _commandName, std::string _oneLineHelp = "");
-  virtual ~ServerCommand();
+    ServerCommand(std::string _commandName, std::string _oneLineHelp = "");
+    virtual ~ServerCommand();
 
-  std::string commandName;
-  std::string oneLineHelp;
+    std::string commandName;
+    std::string oneLineHelp;
 
-  typedef std::map<std::string, ServerCommand *> MapOfCommands;
+    typedef std::map<std::string, ServerCommand *> MapOfCommands;
 
-  static MapOfCommands *mapOfCommands;
+    static MapOfCommands *mapOfCommands;
 };
 
 #endif
 
 // Local Variables: ***
 // mode: C++ ***
-// tab-width: 8 ***
-// c-basic-offset: 2 ***
-// indent-tabs-mode: t ***
+// tab-width: 4 ***
+// c-basic-offset: 4 ***
+// indent-tabs-mode: nil ***
 // End: ***
-// ex: shiftwidth=2 tabstop=8
+// ex: shiftwidth=4 tabstop=4
